
.. include:: ../README.rst

The User Guide
--------------

This part of the documentation, which is mostly prose, begins with some
background information about Curver, then focuses on step-by-step
instructions for getting the most out of Curver.

.. toctree::
   :maxdepth: 2

   user/intro
   user/install
   user/quickstart
   user/surfaces
   user/references
   user/citing
   user/history

The API Documentation
---------------------

If you are looking for information on a specific function, class, or method,
this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   modules

The Contributor Guide
---------------------

If you want to contribute to the project, this part of the documentation is for
you.

.. toctree::
   :maxdepth: 2

   dev/contributing
   dev/philosophy
   dev/todo
   dev/authors

There are no more guides. You are now guideless.
Good luck.

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
